@@ -1,14 +1,11 @@
-# do not show in documentation
-__pdoc__ = {}
-__pdoc__["external"] = False 
+
 
 from dbdicom.create import (
     database,
     series, 
+    zeros,
 )
 from dbdicom.record import (
-    get_values,
-    set_values,
     copy_to, 
     move_to, 
     group, 
