@@ -114,8 +114,8 @@ class Manager():
                 # Create these in the dbdicom folder, not in the original folder.
                 #
                 filepath = os.path.join(self.path, relpath)
-                singleframe_files = dcm4che.split_multiframe(filepath)
-                if singleframe_files != []:                    
+                singleframe_files = dcm4che.split_multiframe(filepath) 
+                if singleframe_files != []:            
                     # add the single frame files to the dataframe
                     df = dbdataset.read_dataframe(singleframe_files, self.columns, path=self.path)
                     df['removed'] = False
@@ -124,7 +124,8 @@ class Manager():
                     self.register = pd.concat([self.register, df])
                     # delete the original multiframe 
                     os.remove(filepath)
-                    self.register.drop(index=relpath, inplace=True)
+                # drop the file also if the conversion has failed
+                self.register.drop(index=relpath, inplace=True)
 
     def _pkl(self):
         """ Returns the file path of the .pkl file"""
@@ -363,6 +364,7 @@ class Manager():
         vals = list(kwargs.values())
         attr = list(kwargs.keys())
         return [id for id in uids if self.get_values(attr, uid=id) == vals]
+        #return [id for id in uids if function(self.get_values(attr, uid=id), vals)]
 
 
     def filter_instances(self, df, **kwargs):
@@ -991,7 +993,7 @@ class Manager():
             #     self.status.progress(i, len(keys), message)
             if key in self.dataset:
                 file = self.filepath(key)
-                self.dataset[key].write(file, self.dialog)
+                self.dataset[key].write(file, self.status)
         #self.status.hide()
 
     def clear(self, *args, keys=None, **kwargs):
@@ -1262,7 +1264,7 @@ class Manager():
                 attributes + ['SOPInstanceUID', 'InstanceNumber'], 
                 values + [new_instance, 1+max_number])
             if not instance_key in self.dataset:
-                ds.write(self.filepath(new_key), self.dialog)
+                ds.write(self.filepath(new_key), self.status)
             row = ds.get_values(self.columns)
 
         # Get new data for the dataframe
@@ -1341,7 +1343,7 @@ class Manager():
                     attributes + ['SOPInstanceUID', 'InstanceNumber'], 
                     values + [new_instances[i], i+1+max_number])
                 if not key in self.dataset:
-                    ds.write(self.filepath(new_key), self.dialog)
+                    ds.write(self.filepath(new_key), self.status)
                 row = ds.get_values(self.columns)
 
             # Get new data for the dataframe
@@ -1423,7 +1425,7 @@ class Manager():
                         attributes + ['SeriesInstanceUID', 'SeriesNumber', 'SOPInstanceUID'], 
                         values + [new_series[s], new_number, dbdataset.new_uid()])
                     if not key in self.dataset:
-                        ds.write(self.filepath(new_key), self.dialog)
+                        ds.write(self.filepath(new_key), self.status)
                     row = ds.get_values(self.columns)
 
                 # Get new data for the dataframe
@@ -1492,7 +1494,7 @@ class Manager():
                             attributes + ['StudyInstanceUID', 'SeriesInstanceUID', 'SOPInstanceUID'], 
                             values + [new_studies[s], new_series_uid, dbdataset.new_uid()])
                         if not key in self.dataset:
-                            ds.write(self.filepath(new_key), self.dialog)
+                            ds.write(self.filepath(new_key), self.status)
                         row = ds.get_values(self.columns)
 
                     # Get new data for the dataframe
@@ -1556,7 +1558,7 @@ class Manager():
                                 list(kwargs.keys())+['PatientID', 'StudyInstanceUID', 'SeriesInstanceUID', 'SOPInstanceUID', 'PatientName'], 
                                 list(kwargs.values())+[new_patient_uid, new_study_uid, new_series_uid, new_instance_uid, new_patient_name])
                             if not key in self.dataset:
-                                ds.write(self.filepath(new_key), self.dialog)
+                                ds.write(self.filepath(new_key), self.status)
                             row = ds.get_values(self.columns)
 
                         # Get new data for the dataframe
@@ -1698,7 +1700,7 @@ class Manager():
                         attributes + ['InstanceNumber'], 
                         values + [i+1 + max_number])
                     if not key in self.dataset:
-                        ds.write(self.filepath(key), self.dialog)
+                        ds.write(self.filepath(key), self.status)
                     for i, col in enumerate(attributes):
                         if col in self.columns:
                             self.register.at[key,col] = values[i]
@@ -1721,7 +1723,7 @@ class Manager():
                         attributes + ['InstanceNumber'], 
                         values + [i+1+max_number])
                     if not key in self.dataset:
-                        ds.write(self.filepath(new_key), self.dialog)
+                        ds.write(self.filepath(new_key), self.status)
 
                     # Get new data for the dataframe
                     row = ds.get_values(self.columns)
@@ -1848,7 +1850,7 @@ class Manager():
                             attributes + ['SeriesNumber'], 
                             values + [new_number])
                         if not key in self.dataset:
-                            ds.write(self.filepath(key), self.dialog)
+                            ds.write(self.filepath(key), self.status)
                         for i, col in enumerate(attributes):
                             if col in self.columns:
                                 self.register.at[key,col] = values[i]
@@ -1871,7 +1873,7 @@ class Manager():
                             attributes + ['SeriesNumber'], 
                             values + [new_number])
                         if not key in self.dataset:
-                            ds.write(self.filepath(new_key), self.dialog)
+                            ds.write(self.filepath(new_key), self.status)
 
                         # Get new data for the dataframe
                         row = ds.get_values(self.columns)
@@ -1983,7 +1985,7 @@ class Manager():
                         if self.value(key, 'created'): 
                             ds.set_values(attributes, values)
                             if not key in self.dataset:
-                                ds.write(self.filepath(key), self.dialog)
+                                ds.write(self.filepath(key), self.status)
                             for i, col in enumerate(attributes):
                                 if col in self.columns:
                                     self.register.at[key,col] = values[i]
@@ -2005,7 +2007,7 @@ class Manager():
                                 self.dataset[new_key] = ds
                             ds.set_values(attributes, values)
                             if not key in self.dataset:
-                                ds.write(self.filepath(new_key), self.dialog)
+                                ds.write(self.filepath(new_key), self.status)
 
                             # Get new data for the dataframe
                             row = ds.get_values(self.columns)
@@ -2092,7 +2094,7 @@ class Manager():
             if self.value(key, 'created'): 
                 ds.set_values(attributes, values)
                 if not key in self.dataset:
-                    ds.write(self.filepath(key), self.dialog)
+                    ds.write(self.filepath(key), self.status)
                 for i, col in enumerate(attributes):
                     if col in self.columns:
                         self.register.at[key,col] = values[i]
@@ -2112,7 +2114,7 @@ class Manager():
                     self.dataset[new_key] = ds
                 ds.set_values(attributes, values)
                 if not key in self.dataset:
-                    ds.write(self.filepath(new_key), self.dialog)
+                    ds.write(self.filepath(new_key), self.status)
 
                 # Get new data for the dataframe
                 row = ds.get_values(self.columns)
@@ -2223,7 +2225,7 @@ class Manager():
         for file in df.index.tolist():
             new_key = self.new_key()
             ds = dbdataset.read(file)
-            ds.write(self.filepath(new_key), self.dialog)
+            ds.write(self.filepath(new_key), self.status)
             df.rename(index={file:new_key}, inplace=True)
         self.register = pd.concat([self.register, df])
 
